# Generated by Django 6.0 on 2025-12-17 00:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('orbit', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='orbitentry',
            name='type',
            field=models.CharField(choices=[('request', 'HTTP Request'), ('query', 'SQL Query'), ('log', 'Log Entry'), ('exception', 'Exception'), ('job', 'Background Job'), ('command', 'Command'), ('cache', 'Cache'), ('model', 'Model Event'), ('http_client', 'HTTP Client')], db_index=True, help_text='Type of telemetry entry', max_length=20),
        ),
    ]
