# Generated by Django 6.0 on 2026-01-22 23:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("orbit", "0003_alter_orbitentry_type"),
    ]

    operations = [
        migrations.AlterField(
            model_name="orbitentry",
            name="type",
            field=models.CharField(
                choices=[
                    ("request", "HTTP Request"),
                    ("query", "SQL Query"),
                    ("log", "Log Entry"),
                    ("exception", "Exception"),
                    ("job", "Background Job"),
                    ("command", "Command"),
                    ("cache", "Cache"),
                    ("model", "Model Event"),
                    ("http_client", "HTTP Client"),
                    ("dump", "Dump"),
                    ("mail", "Mail"),
                    ("signal", "Signal"),
                    ("redis", "Redis"),
                    ("gate", "Gate/Policy"),
                    ("transaction", "Transaction"),
                    ("storage", "Storage"),
                ],
                db_index=True,
                help_text="Type of telemetry entry",
                max_length=20,
            ),
        ),
    ]
